import { Fragment, useEffect, useRef, useState } from "react";
import "./index.css";
import * as CodeMirror from "codemirror/lib/codemirror";
import "codemirror/lib/codemirror.css";
import "codemirror/mode/htmlmixed/htmlmixed";
import "codemirror/theme/monokai.css";
import "codemirror/addon/scroll/simplescrollbars";
import "codemirror/addon/scroll/simplescrollbars.css";
import { CODE as CODE_TOUCH } from "./touchevent";
import { Button, Message, PageHeader, Radio } from "@arco-design/web-react";
import "@arco-design/web-react/dist/css/arco.css";
import copy from "copy-to-clipboard";
import axios from "axios";

Message.config({ maxCount: 1 });

const Index = props => {
  const [iframeSrc, setIframeSrc] = useState("");
  const [demoLoading, setDemoLoading] = useState(true);
  const [edited, setEdited] = useState(false);
  const cm = useRef(null);
  const code = useRef({});

  useEffect(() => {
    initCodeMirror();
    closeLoading();
    readFile();
  }, []);

  const readFile = () => {
    axios.get("/demo/sdk/index.mobile.html").then((res) => {
      setIframeSrc(res.data);
      cm.current.setValue(res.data);
      setEdited(false);
      code.current.CODE = res.data;
    });
    axios.get("/demo/sdk/index.mobile.all-portrait.html").then((res) => {
      code.current.CODE_PORTRAIT = res.data;
    });
    axios.get("/demo/sdk/index.mobile.all.html").then((res) => {
      code.current.CODE_MOBILE = res.data;
    });
    axios.get("/demo/sdk/index.mobile.pip.html").then((res) => {
      code.current.CODE_PIP = res.data;
    });
  };

  const initCodeMirror = () => {
    cm.current = CodeMirror.fromTextArea(document.getElementById("editor"), {
      mode: "htmlmixed",
      theme: "monokai",
      extraKeys: { Ctrl: "autocomplete" },
      lineNumbers: true,
      value: "",
      lineWrapping: true,
      scrollbarStyle: "overlay",
    });
    cm.current.setSize("", "100%");
    cm.current.on("changes", () => setEdited(true));
  };

  const changeDemo = (mode) => {
    let str = "";
    switch (mode) {
      case "portrait":
        str = code.current.CODE_PORTRAIT;
        break;
      case "mobile":
          str = code.current.CODE_MOBILE;
          break;
      case "pip":
        str = code.current.CODE_PIP;
        break;
      default:
        str = code.current.CODE;
    }
    closeLoading();
    setIframeSrc(str);
    cm.current.doc.setValue(str);
    setEdited(false);
  };

  const goNow = () => {
    setIframeSrc(cm.current.doc.getValue());
    setEdited(false);
    closeLoading();
  };

  const closeLoading = () => {
    setDemoLoading(true);
    setTimeout(() => setDemoLoading(false), 2000);
  };

  const handleCopy = () => {
    copy(cm.current.doc.getValue());
    Message.success("Copied");
  };

  return (
    <div className="container">
      <PageHeader
        style={{ background: "var(--color-bg-2)" }}
        title="BytePlus Live Web SDK"
        subTitle={
          <Fragment>
            demo playground for Mobile &nbsp;&nbsp;
            <a
              target="_blank"
              href="https://bytedance.feishu.cn/wiki/wikcn26sRkfga41KsSuv9pBBo6g"
              style={{
                color: "rgb(var(--primary-6))",
                textDecoration: "none",
              }}
              rel="noreferrer"
            >
              How to integrate
            </a>
            <Button
              type="primary"
              style={{ marginLeft: 12 }}
              onClick={() => {
                props.setIsPc(true);
                window.history.pushState({}, '', 'index.playground.html?mode=pc');
              }}
            >
              Switch to Demo for PC
            </Button>
          </Fragment>
        }
        extra={
          <div>
            <Button
              type="primary"
              style={{ marginRight: 12 }}
              onClick={goNow}
              loading={demoLoading}
              disabled={!edited}
            >
              Preview now
            </Button>
            <Button
              type="outline"
              style={{ marginRight: 12 }}
              onClick={handleCopy}
            >
              Copy
            </Button>
            <Radio.Group
              mode="fill"
              type="button"
              size="large"
              defaultValue="default"
              onChange={changeDemo}
            >
              <Radio value="default">Standard Live</Radio>
              <Radio value="mobile">Live using full page module</Radio>
              <Radio value="portrait">Portrait Live</Radio>
              <Radio value="pip">Live with PIP</Radio>
            </Radio.Group>
          </div>
        }
      />
      <div className="bottom-container">
        <div className="iframe-container">
          {iframeSrc && (
            <iframe
              style={{ width: 412, height: 800 }}
              title="mobile preview"
              srcDoc={iframeSrc.replace(
                "<title>BytePlus Live Web SDK DEMO</title>",
                CODE_TOUCH
              )}
            ></iframe>
          )}
          <div style={{ color: "#fff", marginTop: "12px" }}>
            * Some features are not available here due to difference of click and touch events 
          </div>
        </div>
        <div className="cmContainer">
          <textarea id="editor"></textarea>
        </div>
      </div>
    </div>
  );
};

export default Index;

