import { Button, Message, PageHeader, Drawer, Radio } from "@arco-design/web-react";
import { Fragment, useEffect, useRef, useState } from "react";
import "@arco-design/web-react/dist/css/arco.css";
import copy from "copy-to-clipboard";
import axios from "axios";
import * as CodeMirror from "codemirror/lib/codemirror";
import "codemirror/lib/codemirror.css";
import "codemirror/mode/htmlmixed/htmlmixed";
import "codemirror/theme/monokai.css";
import "codemirror/addon/scroll/simplescrollbars";
import "codemirror/addon/scroll/simplescrollbars.css";
import { code as CODE_CUSTOM} from './pcCode';

const Index = props => {
  const [iframeSrc, setIframeSrc] = useState("");
  const [cmInitCode, setCmInitCode] = useState("");
  const [demoLoading, setDemoLoading] = useState(true);
  const [edited, setEdited] = useState(false);
  const cm = useRef(null);
  const code = useRef({});
  const [codeShow, setCodeShow] = useState(false);
  const [currentTab, setCurrentTab] = useState('default');

  useEffect(() => {
    closeLoading();
    readFile();
  }, []);

  const readFile = () => {
    axios.get("/demo/sdk/index.pc.html").then((res) => {
      setIframeSrc(res.data);
      setCmInitCode(res.data);
      // cm.current.setValue(res.data);
      code.current.CODE = res.data;
    });
    // axios.get("/demo/sdk/custom.auth.pc.html").then((res) => {
    //   code.current.CUSTOM = res.data;
    // });
  };

  const initCodeMirror = () => {
    cm.current = CodeMirror.fromTextArea(document.getElementById("editor"), {
      mode: currentTab === 'javascript' ? '' : 'htmlmixed',
      theme: "monokai",
      extraKeys: { Ctrl: "autocomplete" },
      lineNumbers: true,
      value: "",
      lineWrapping: true,
      scrollbarStyle: "overlay",
    });
    cm.current.setValue(cmInitCode);
    cm.current.setSize("", "100%");
    cm.current.on("changes", () => setEdited(true));
  };

  const goNow = () => {
    setIframeSrc(cm.current.doc.getValue());
    setCodeShow(false);
    closeLoading();
  };

  const openModal = () => {
    setCodeShow(true);
    setTimeout(() => {
      if (cm.current) {
        cm.current.setOption('mode', currentTab === 'custom' ? 'javascript' : 'htmlmixed')
      } else {
        initCodeMirror();
      }
    }, 300);
  }

  const closeLoading = () => {
    setDemoLoading(true);
    setTimeout(() => {
      setDemoLoading(false);
    }, 2000);
  };

  const handleCopy = () => {
    copy(cm.current.doc.getValue());
    Message.success("Copied");
  };

  const changeDemo = (mode) => {
    let str = "";
    let cmCode = "";
    switch (mode) {
      case "custom":
        str = code.current.CUSTOM;
        cmCode = CODE_CUSTOM;
        break;
      case "default":
      default:
        str = code.current.CODE;
        cmCode = code.current.CODE;
    }
    if (cm.current) {
      cm.current.doc.setValue(cmCode);
      console.log(123);
    }
    setCurrentTab(mode);
    setCmInitCode(cmCode);
    closeLoading();
    setEdited(false);
    setIframeSrc(str);
  };

  return (
    <div className="container">
      <PageHeader
        style={{ background: "var(--color-bg-2)" }}
        title="BytePlus Live Web SDK"
        subTitle={
          <Fragment>
            demo playground for PC &nbsp;&nbsp;
            <a
              target="_blank"
              href="https://bytedance.feishu.cn/wiki/wikcn26sRkfga41KsSuv9pBBo6g"
              style={{
                color: "rgb(var(--primary-6))",
                textDecoration: "none",
              }}
              rel="noreferrer"
            >
              How to integrate
            </a>
            <Button
              type="primary"
              style={{ marginLeft: 12 }}
              onClick={() => {
                props.setIsPc(false);
                window.history.pushState({}, '', 'index.playground.html');
              }}
            >
              Switch to Demo for Mobile
            </Button>
          </Fragment>
        }
        extra={
          <div>
            <Button
              type="primary"
              style={{ marginRight: 12 }}
              onClick={openModal}
              loading={demoLoading}
            >
              {currentTab === 'custom' ? 'View Code' : 'Edit code'}
            </Button>
            <Radio.Group
              mode="fill"
              type="button"
              size="large"
              defaultValue="default"
              onChange={changeDemo}
            >
              <Radio value="default">Standard Live</Radio>
              {/* <Radio value="custom">第三方用户态直播间</Radio> */}
            </Radio.Group>
          </div>
        }
      />
      <div className="bottom-container">
        {iframeSrc && (
          <iframe
            style={{ width: '100%', height: '100%', border: 'none' }}
            title="pc preview"
            srcDoc={iframeSrc}
          ></iframe>
        )}
      </div>
      <Drawer 
        title='Code Editor'
        visible={codeShow}
        footer={null}
        mountOnEnter={false}
        onConfirm={goNow}
        onCancel={() => setCodeShow(false)}
        width={'60%'}
        unmountOnExit={false}
      >
        <div className="pc-drawer-content">
          <div style={{ textAlign: 'right' }}>
            {currentTab !== 'custom' && <Button
              type="primary"
              style={{ marginRight: 12 }}
              onClick={goNow}
              loading={demoLoading}
              disabled={!edited}
            >
              Preview Now
            </Button>}
          <Button
              type="outline"
              style={{ marginRight: 12 }}
              onClick={handleCopy}
            >
              Copy
            </Button>
          </div>
          <div className="cmContainer" style={{ marginRight: 0, marginBottom: 0 }}>
            <textarea id="editor" style={{ display: 'none' }}></textarea>
          </div>
        </div>
      </Drawer>
    </div>
  )
}

export default Index;